@@ -25,6 +25,7 @@ class Group(SignalEvent, list):
         self.lock_signal = False
         self.parent = parent
         self.parent_name = parent_name or ''
+        self.children = []
         self.child_name = child_name
         self.parent_datetime_field = parent_datetime_field
         self._context = context or {}
@@ -42,6 +43,9 @@ class Group(SignalEvent, list):
         self.pool = WeakSet()
         self.skip_model_access = False
 
+        if self.parent and self.parent.model_name == model_name:
+            self.parent.group.children.append(self)
+
     @property
     def readonly(self):
         # Must skip res.user for Preference windows
@@ -113,7 +117,7 @@ class Group(SignalEvent, list):
         if idx >= 1:
             if idx + 1 < self.__len__():
                 self.__getitem__(idx - 1).next[id(self)] = \
-                        self.__getitem__(idx + 1)
+                    self.__getitem__(idx + 1)
             else:
                 self.__getitem__(idx - 1).next[id(self)] = None
         self.signal('group-list-changed', ('record-removed', record))
@@ -166,8 +170,8 @@ class Group(SignalEvent, list):
             self.delete(self.record_deleted)
         return saved
 
-    def delete(self, records, context=None):
-        return Record.delete(records, context=context)
+    def delete(self, records):
+        return Record.delete(records)
 
     @property
     def root_group(self):
@@ -188,8 +192,11 @@ class Group(SignalEvent, list):
         return ids
 
     def reload(self, ids):
-        for record in self:
-            if record.id in ids and not record.modified:
+        for child in self.children:
+            child.reload(ids)
+        for id_ in ids:
+            record = self.get(id_)
+            if record and not record.modified:
                 record._loaded.clear()
 
     def on_write_ids(self, ids):
@@ -199,12 +206,12 @@ class Group(SignalEvent, list):
         for fnct in self.on_write:
             try:
                 res += RPCExecute('model', self.model_name, fnct, ids,
-                    context=self.context)
+                    main_iteration=False, context=self.context)
             except RPCException:
                 return []
         return list({}.fromkeys(res))
 
-    def load(self, ids, display=True, modified=False, id2record=None):
+    def load(self, ids, modified=False):
         if not ids:
             return True
 
@@ -235,9 +242,6 @@ class Group(SignalEvent, list):
             self.lock_signal = False
             self.signal('group-cleared')
 
-        if new_records and display:
-            self.signal('group-changed', new_records[0])
-
         if new_records and modified:
             new_records[0].signal('record-modified')
             new_records[0].signal('record-changed')
@@ -251,16 +255,16 @@ class Group(SignalEvent, list):
             ctx.update(self.parent.context_get())
             if self.child_name in self.parent.group.fields:
                 field = self.parent.group.fields[self.child_name]
-                ctx.update(field.context_get(self.parent, check_load=False))
+                ctx.update(field.context_get(self.parent))
         ctx.update(self._context)
         if self.parent_datetime_field:
-            ctx['_datetime'] = self.parent.get_eval(check_load=False
+            ctx['_datetime'] = self.parent.get_eval(
                 )[self.parent_datetime_field]
         return ctx
 
     context = property(_get_context)
 
-    def add(self, record, position=-1, modified=True):
+    def add(self, record, position=-1):
         if record.group is not self:
             record.signal_unconnect(record.group)
             record.group = self
@@ -278,29 +282,34 @@ class Group(SignalEvent, list):
             if record_del.id == record.id:
                 self.record_deleted.remove(record)
         self.current_idx = position
-        if modified:
-            record.modified_fields.setdefault('id')
-            record.signal('record-modified')
+        record.modified_fields.setdefault('id')
+        record.signal('record-modified')
         self.signal('group-changed', record)
         return record
 
     def set_sequence(self, field='sequence'):
         index = 0
+        changed = False
         for record in self:
             if record[field]:
                 if index >= record[field].get(record):
                     index += 1
-                    record[field].set_client(record, index)
+                    record.signal_unconnect(self, 'record-changed')
+                    try:
+                        record[field].set_client(record, index)
+                    finally:
+                        record.signal_connect(self, 'record-changed',
+                            self._record_changed)
+                    changed = record
                 else:
                     index = record[field].get(record)
+        if changed:
+            self.signal('group-changed', changed)
 
-    def new(self, default=True, domain=None, context=None, obj_id=None):
+    def new(self, default=True, obj_id=None):
         record = Record(self.model_name, obj_id, group=self)
         if default:
-            ctx = {}
-            ctx.update(context or {})
-            ctx.update(self.context)
-            record.default_get(domain, ctx)
+            record.default_get()
         record.signal_connect(self, 'record-changed', self._record_changed)
         record.signal_connect(self, 'record-modified', self._record_modified)
         return record
@@ -366,10 +375,7 @@ class Group(SignalEvent, list):
             return None
         return self[self.current_idx]
 
-    def add_fields(self, fields, context=None, signal=True):
-        if context is None:
-            context = {}
-
+    def add_fields(self, fields, signal=True):
         to_add = {}
         for name, attr in fields.iteritems():
             if name not in self.fields:
@@ -385,13 +391,11 @@ class Group(SignalEvent, list):
         for record in self:
             if record.id < 0:
                 new.append(record)
-        ctx = context.copy()
 
         if len(new) and len(to_add):
-            ctx.update(self.context)
             try:
                 values = RPCExecute('model', self.model_name, 'default_get',
-                    to_add.keys(), context=ctx)
+                    to_add.keys(), main_iteration=False, context=self.context)
             except RPCException:
                 return False
             for name in to_add:
@@ -411,6 +415,11 @@ class Group(SignalEvent, list):
         del self.__id2record[old_id]
 
     def destroy(self):
+        if self.parent:
+            try:
+                self.parent.group.children.remove(self)
+            except ValueError:
+                pass
         self.clear()
         super(Group, self).destroy()
         self.parent = None
